<?php

/**
 * This class works with dummy content list.
 *
 * @since      1.0.0
 *
 * @package    DT_Dummy
 * @subpackage DT_Dummy/includes
 */

/**
 * This class works with dummy content list.
 *
 * @package    DT_Dummy
 * @subpackage DT_Dummy/includes
 * @author     Dream-Theme
 */
class DT_Dummy_Content {

	private $content_pointer;
	private $dummy_content;
	private $current_content;

	public function __construct( $dummy_content, $theme_name ) {
		if ( array_key_exists( $theme_name, $dummy_content ) ) {
			$this->dummy_content = $dummy_content[ $theme_name ];
		}

		$this->reset_pointer();
		$this->current_content = $this->get_current_content();
	}

	public function have_content() {
		return array_key_exists( $this->content_pointer, $this->dummy_content );
	}

	public function reset_content() {
		$this->reset_pointer();
	}

	public function next_content_part() {
		$this->current_content = $this->get_current_content();
		$this->inc_pointer();
	}

	public function get_content_info() {
		return new DT_Dummy_Content_Part( $this->get_current_content_part( 'info' ) );
	}

	public function get_main_content() {
		return new DT_Dummy_Content_Part( $this->get_current_content_part( 'dummy_content' ) );
	}

	public function get_wc_content() {
		return new DT_Dummy_Content_Part( $this->get_current_content_part( 'wc_dummy_content' ) );
	}

	private function get_current_content() {
		if ( ! $this->have_content() ) {
			return array();
		}

		return $this->dummy_content[ $this->content_pointer ];
	}

	private function get_current_content_part( $key, $default = array() ) {
		if ( empty( $this->current_content[ $key ] ) || ! is_array( $this->current_content[ $key ] ) ) {
			return $default;
		}

		return $this->current_content[ $key ];
	}

	private function inc_pointer() {
		$this->content_pointer++;
	}

	private function reset_pointer() {
		$this->content_pointer = 0;
	}
}

class DT_Dummy_Content_Part {
	private $content_part;

	public function __construct( $content_part ) {
		$this->content_part = $content_part;
		reset( $this->content_part );
	}

	public function is_empty() {
		return empty( $this->content_part );
	}

	public function get( $key ) {
		if ( ! array_key_exists( $key, $this->content_part ) ) {
			return false;
		}
		return $this->content_part[ $key ];
	}

	public function next() {
		return next( $this->content_part );
	}

	public function end() {
		return end( $this->content_part );
	}

	public function reset() {
		return reset( $this->content_part );
	}

	public function as_array() {
		return $this->content_part;
	}
}
